| mlr_learners_regr.fairfrrm | R Documentation |
If more than one pta columns are provided, the hyperparameter intersectional controls whether
intersections of protected groups are formed (e.g. combinations of gender and race).
Initialized to TRUE.
If FALSE, only the group specified by the first element of pta is used.
Calls fairml::frrm from package fairml.
Fair ridge regression learner implemented via package fairml.
The 'unfairness' parameter has been initialized to 0.05.
This Learner can be instantiated via the
dictionary mlr_learners or with the associated
sugar function lrn():
mlr_learners$get("regr.fairfrrm")
lrn("regr.fairfrrm")
Task type: “regr”
Predict Types: “response”
Feature Types: “integer”, “numeric”, “factor”, “ordered”
| Id | Type | Default | Levels | Range |
| lambda | numeric | 0 | [0, \infty) |
|
| definition | character | sp-komiyama | sp-komiyama, eo-komiyama | - |
| save.auxiliary | logical | FALSE | TRUE, FALSE | - |
| unfairness | numeric | - | [0, 1] |
|
mlr3::Learner -> mlr3::LearnerRegr -> LearnerRegrFairfrrm
new()Creates a new instance of this R6 class.
LearnerRegrFairfrrm$new()
clone()The objects of this class are cloneable with this method.
LearnerRegrFairfrrm$clone(deep = FALSE)
deepWhether to make a deep clone.
pfistfl
Scutari M, Panero F, Proissl M (2021). “Achieving Fairness with a Simple Ridge Penalty.” arXiv preprint arXiv:2105.13817.
Dictionary of Learners: mlr3::mlr_learners
Other fairness_learners:
mlr_learners_classif.fairfgrrm,
mlr_learners_classif.fairzlrm,
mlr_learners_regr.fairnclm,
mlr_learners_regr.fairzlm
library("mlr3")
# stop example failing with warning if package not installed
learner = suppressWarnings(mlr3::lrn("regr.fairfrrm"))
print(learner)
# available parameters:
learner$param_set$ids()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.